==> gc_data_storage-0.1.6.tar.gz: gc_data_storage-0.1.6/setup.py <==
from setuptools import setup, find_packages

setup(
    name='gc_data_storage',
    version='0.1.6',
    author='Aymone Jeanne Kouame',
    author_email='aymone.jk@gmail.com',
    description= "Python utility for data storage in Google Cloud Environments.",
    long_description= """
gc_data_storage lets you easily move data between your development environment (e.g. Jupyter Notebook) and your Google Cloud Workspace bucket. It integrates the ccommand line too gsutil.

 * Save data from your development environment to the bucket.

 * Read data from the bucket into your development environment, with the option to keep a copy in the persistent disk.

 * Copy data between different directories within the bucket or between two different buckets owned by the user.

 * Obtain a list of data saved in the bucket or the persistent disk.

gc_data_storage was originally written to be used within the Research All od Us Researcher Workbench environment
code snippet:

```
pip install gc_data_storage
from gc_data_storage import gc_data_storage as gs
gs = gs(bucket = 'gs://your-bucket-name')
gs.list_saved_data()

```

More information, including examples, at https://github.com/AymoneKouame/gc_data_storage.

""",
    long_description_content_type="text/markdown",
   install_requires=['pyarrow', 'openpyxl'],   
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        ],
    python_requires='>=3.6',
)

==> gc_data_storage-0.1.7.tar.gz: gc_data_storage-0.1.7/setup.py <==
from setuptools import setup, find_packages

setup(
    name='gc_data_storage',
    version='0.1.7',
    author='Aymone Jeanne Kouame',
    author_email='aymone.jk@gmail.com',
    description= "Python utility for data storage in Google Cloud Environments.",
    long_description= """
gc_data_storage lets you easily move data between your development environment (e.g. Jupyter Notebook) and your Google Cloud Workspace bucket. It integrates the ccommand line too gsutil.

 * Save data from your development environment to the bucket.

 * Read data from the bucket into your development environment, with the option to keep a copy in the persistent disk.

 * Copy data between different directories within the bucket or between two different buckets owned by the user.

 * Obtain a list of data saved in the bucket or the persistent disk.

gc_data_storage was originally written to be used within the All of Us Researcher Workbench environment but can be used in other Google Cloud Environments.

code snippet:

```
#pip install gc-data-storage

from gc_data_storage import gc_data_storage as gs
gs = gs(bucket = 'gs://your-bucket-name')
gs.list_saved_data()

```

More information, including examples, at https://github.com/AymoneKouame/gc_data_storage.

""",
    long_description_content_type="text/markdown",
   install_requires=['pyarrow>=19.0.1', 'openpyxl>=3.1.5'],   
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        ],
    python_requires='>=3.6',
)
